"""
This module contains functions, which is used to calculate the form factors
"""
import numpy as np

def homogeneous_sphere(q, R):
    """
    Calculate the form factor of a homogeneous sphere.
    (entirely generated by GitHub Copilot)

    Parameters
    ----------
    q : float or array-like
        The scattering vector magnitude.
    R : float
        The radius of the sphere.

    Returns
    -------
    F : float or array-like
        The form factor of the homogeneous sphere.
    """
    # Calculate the form factor using the formula for a homogeneous sphere
    F = (3 * (np.sin(q * R) - q * R * np.cos(q * R))) / (q * R)**3
    return F